@@ -1,5 +1,5 @@
 
-from docker_registry.core import compat
+import docker_registry.core.boto as  coreboto
 from docker_registry.core import driver
 from docker_registry.core import exceptions
 from docker_registry.core import lru
@@ -14,7 +14,7 @@ from jss.connection import JssClient
 logger = logging.getLogger(__name__)
 json = compat.json
 
-class Storage(driver.Base):
+class Storage(coreboto.Base):
 
     def __init__(self, path=None, config=None):
         self._access_key = config.jss_accesskey
@@ -40,14 +40,14 @@ class Storage(driver.Base):
         
         return object_instance.generate_url("GET")
     
-    def get_json(self, path):
-        logger.info("get_json path:%s" % path)
-        try:
-            return json.loads(self.get_unicode(path))
-        except Exception as e:
-            logger.error("get_json error:%s" % e)
-            return []
-        
+#    def get_json(self, path):
+#        logger.info("get_json path:%s" % path)
+#        try:
+#            return json.loads(self.get_unicode(path))
+#        except Exception as e:
+#            logger.error("get_json error:%s" % e)
+#            return []
+#        
     @lru.get
     def get_content(self, path):
         logger.info("get_content path:%s" % path)
